@@ -1,4 +1,4 @@
 # defining global variables
 # ugly solution to avoid magrittr NOTE
 # see http://stackoverflow.com/questions/9439256/how-can-i-handle-r-cmd-check-no-visible-binding-for-global-variable-notes-when
-globalVariables(".")
+globalVariables(c(".", "dataset"))
